#[non_exhaustive]pub enum PdfError {
MissingEmbeddedFont {
font_id: u32,
},
InvalidStructure,
ForbiddenAction {
action: String,
},
UnsupportedColor,
UnsupportedPaint {
paint: &'static str,
},
}Expand description
A reason an input cannot be represented by the requested PDF/A profile.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingEmbeddedFont
A shaped run refers to a font that cannot be embedded and subset.
InvalidStructure
The logical structure tree or one of its marked-content references is invalid.
ForbiddenAction
A link requests an action that the archival path refuses.
UnsupportedColor
A color component is non-finite or outside its declared range.
UnsupportedPaint
A paint kind has no archival PDF representation.