#[non_exhaustive]pub enum RasterError {
InvalidDpi,
EmptyPageSelection,
PageOutOfRange {
page_index: usize,
page_count: usize,
},
DuplicatePage {
page_index: usize,
},
InvalidJpegQuality {
quality: u8,
},
InvalidDimensions,
EncodeFailed {
format: &'static str,
},
}Expand description
A reason a raster export request could not be completed.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidDpi
DPI was NaN, infinite, zero, or negative.
EmptyPageSelection
No page was selected.
PageOutOfRange
A selected zero-based page index does not exist.
DuplicatePage
A selected zero-based page index appears more than once.
InvalidJpegQuality
JPEG quality must be in the inclusive 1 through 100 range.
InvalidDimensions
The requested raster dimensions cannot be represented.
EncodeFailed
The rendered pixmap could not be encoded into the requested format.